ReadParam

Struct ReadParam 

pub struct ReadParam<'node> { /* private fields */ }
The “read command received” state. The bus controller expects a reply with the current value of the specified parameter.

Implementations

Source

impl<'node> ReadParam<'node>

pub fn send_reply_ok(self, value: Value) -> StateToken

Send a response to the master with the value of the parameter in the read request.

pub fn send_invalid_parameter(self) -> StateToken

Inform the master that the parameter in the request is invalid.

pub fn send_read_failed(self) -> StateToken

Inform the bus master that the read request failed for some reason other than invalid parameter number.

pub fn no_reply(self) -> StateToken

Do not send any reply to the master. Transition to the idle ReceiveData state instead. You really shouldn’t do this, since this will leave the master waiting until it times out.

pub const fn address(&self) -> Address

Get the address the request was sent to.

pub const fn parameter(&self) -> Parameter

The parameter whose value is to be returned.