WriteParam

Struct WriteParam 

pub struct WriteParam<'node> { /* private fields */ }
“Write command received” state. The bus controller wants to change the value of the specified parameter.

Implementations

Source

impl<'node> WriteParam<'node>

pub fn write_ok(self) -> StateToken

Inform the bus controller that the parameter value was successfully updated.

pub fn write_error(self) -> StateToken

The parameter or value is invalid, or something else is preventing us from setting the parameter to the given value.

pub fn no_reply(self) -> StateToken

Do not send any reply to the bus controller. Transition to the idle ReceiveData state instead. You should avoid this, since this will leave the controller waiting until it times out.

pub const fn address(&self) -> Address

The address the write request was sent to.

pub const fn parameter(&self) -> Parameter

The parameter to be written.

pub const fn value(&self) -> Value

The new value for the parameter.