pub struct WriteParam<'node> { /* private fields */ }Expand description
“Write command received” state. The bus controller wants to change the value of the specified parameter.
Implementations
Sourceimpl<'node> WriteParam<'node>
impl<'node> WriteParam<'node>
Sourcepub fn write_ok(self) -> StateToken
pub fn write_ok(self) -> StateToken
Inform the bus controller that the parameter value was successfully updated.
Sourcepub fn write_error(self) -> StateToken
pub fn write_error(self) -> StateToken
The parameter or value is invalid, or something else is preventing us from setting the parameter to the given value.
Sourcepub fn no_reply(self) -> StateToken
pub fn no_reply(self) -> StateToken
Do not send any reply to the bus controller. Transition to the idle ReceiveData state instead.
You should avoid this, since this will leave the controller waiting until it times out.